Struct libmount::Remount [] [src]

pub struct Remount { /* fields omitted */ }

A remount definition

Usually it is used to change mount flags for a mounted filesystem. Especially to make a readonly filesystem writable or vice versa.

Methods

impl Remount
[src]

[src]

Create a new Remount operation

By default it doesn't modify any flags. So is basically useless, you should set some flags to make it effective.

[src]

Set bind flag Note: remount readonly doesn't work without MS_BIND flag inside unpriviledged user namespaces

[src]

Set readonly flag

[src]

Set nodev flag

[src]

Set noexec flag

[src]

Set nosuid flag

[src]

Set noatime flag

[src]

Set nodiratime flag

[src]

Set relatime flag

[src]

Set strictatime flag

[src]

Set dirsync flag

[src]

Set synchronous flag

[src]

Set mandlock flag

[src]

Execute a remount

[src]

Execute a remount and explain the error immediately