Struct libmount::BindMount
[−]
[src]
pub struct BindMount {
// some fields omitted
}A mount bind definition
By default bind mount is recursive (it's what you want most of the time).
Also recursive mounts can be used in user namespaces.
Methods
impl BindMount[src]
fn new<A: AsRef<Path>, B: AsRef<Path>>(source: A, target: B) -> BindMount
Create a new, recursive bind mount
You can disable recursion with a non_recursive() method
fn recursive(self, flag: bool) -> BindMount
Toggle recursion
fn bare_mount(self) -> Result<(), OSError>
Execute a bind mount
fn mount(self) -> Result<(), Error>
Execute a bind mount and explain the error immediately