Struct libmount::Error [] [src]

pub struct Error(_, _, _);

The error holder which contains as much information about why failure happens as the library implementors could gain

This type only provides Display for now, but some programmatic interface is expected in future.