Struct libmount::Remount
[−]
[src]
pub struct Remount { /* fields omitted */ }A remount definition
Usually it is used to change mount flags for a mounted filesystem. Especially to make a readonly filesystem writable or vice versa.
Methods
impl Remount[src]
pub fn new<A: AsRef<Path>>(path: A) -> Remount[src]
Create a new Remount operation
By default it doesn't modify any flags. So is basically useless, you should set some flags to make it effective.
pub fn bind(self, flag: bool) -> Remount[src]
Set bind flag Note: remount readonly doesn't work without MS_BIND flag inside unpriviledged user namespaces
pub fn readonly(self, flag: bool) -> Remount[src]
Set readonly flag
pub fn nodev(self, flag: bool) -> Remount[src]
Set nodev flag
pub fn noexec(self, flag: bool) -> Remount[src]
Set noexec flag
pub fn nosuid(self, flag: bool) -> Remount[src]
Set nosuid flag
pub fn noatime(self, flag: bool) -> Remount[src]
Set noatime flag
pub fn nodiratime(self, flag: bool) -> Remount[src]
Set nodiratime flag
pub fn relatime(self, flag: bool) -> Remount[src]
Set relatime flag
pub fn strictatime(self, flag: bool) -> Remount[src]
Set strictatime flag
pub fn dirsync(self, flag: bool) -> Remount[src]
Set dirsync flag
pub fn synchronous(self, flag: bool) -> Remount[src]
Set synchronous flag
pub fn mandlock(self, flag: bool) -> Remount[src]
Set mandlock flag
pub fn bare_remount(self) -> Result<(), OSError>[src]
Execute a remount
pub fn remount(self) -> Result<(), Error>[src]
Execute a remount and explain the error immediately